@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::pause_id;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -61,6 +61,9 @@ Updated with updates since November 2006, and
 received its own version number for Acme-MetaSyntactic-Themes version 1.000,
 published on May 7, 2012.
 
+Updated from the source web site for v1.001,
+published in Acme-MetaSyntactic-Themes v1.003, May 28, 2012.
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -161,6 +164,7 @@ ADAMK
 ADAMOWSKI
 ADAMSJ
 ADAMSON
+ADAMZ
 ADAPAY
 ADARSHTP
 ADAVIES
@@ -176,6 +180,7 @@ ADIPALMA
 ADIRAJ
 ADITTES
 ADITYA
+ADITYADEV
 ADIZERE
 ADODGE
 ADONG
@@ -418,6 +423,7 @@ ANAGHAKK
 ANAK
 ANALL
 ANALOG
+ANAND
 ANARION
 ANATRA
 ANAZAWA
@@ -532,6 +538,7 @@ ARAAB
 ARACKHAEN
 ARAK
 ARANDAL
+ARAVIND
 ARAVINDR
 ARC
 ARCANEZ
@@ -617,6 +624,7 @@ ASHISHKU
 ASHISHM
 ASHLEY
 ASHLEYP
+ASHLEYW
 ASHOOOO
 ASHTED
 ASHUTOSH
@@ -1268,6 +1276,7 @@ BUGGYD
 BUGONI
 BUGOV
 BULB
+BULKDD
 BUMBY
 BUNDACIA
 BUNTAR
@@ -1792,6 +1801,7 @@ CTLARSEN
 CTRLSOFT
 CTRONDLP
 CTWETEN
+CUACK
 CUB
 CUBABIT
 CUBRID
@@ -1885,6 +1895,7 @@ DANMQ
 DANMURRAY
 DANN
 DANNY
+DANOCPANO
 DANPEDER
 DANSCH
 DANSMITH
@@ -2354,6 +2365,7 @@ DOWEN
 DOWENS
 DOWNHOM
 DOY
+DOZZIE
 DPARIS
 DPATES
 DPAVLIN
@@ -2717,6 +2729,7 @@ EROB
 EROLLINS
 EROSS
 ERRR
+ERSHOV
 ERUBER
 ERUBY
 ERWAN
@@ -2785,6 +2798,7 @@ FABPOT
 FABRICODE
 FABRVEC
 FAFI
+FAGLIONIG
 FAGZAL
 FAHAD
 FAICHNEY
@@ -2868,6 +2882,7 @@ FIXLER
 FJC
 FJCABRERA
 FJH
+FKALTER
 FKIORI
 FKOENEN
 FKOLODNY
@@ -2928,6 +2943,7 @@ FPMIP
 FPORCHER
 FPREICH
 FRACOLO
+FRACTAL
 FRAG
 FRAJULAC
 FRAMM
@@ -3592,6 +3608,7 @@ HPYHACKER
 HRAFNKELL
 HRANICKY
 HRG
+HRIDAY
 HRK
 HROGERS
 HROMI
@@ -3674,6 +3691,7 @@ IDO
 IDOPEREL
 IDORU
 IEFREMOV
+IFIM
 IFLAN
 IFOMICHEV
 IFROL
@@ -3876,6 +3894,7 @@ JAMESODEN
 JAMESP
 JAMESPO
 JAMESR
+JAMESS
 JAMESTHOM
 JAMHED
 JAMSHAID
@@ -4015,6 +4034,7 @@ JDB
 JDBOYD
 JDCORRAL
 JDDIXON
+JDDPAUSE
 JDELUISE
 JDENNIS
 JDEPERI
@@ -4571,6 +4591,7 @@ JURUEN
 JUSTER
 JUSTEW
 JUSTIN
+JUSTINL
 JUSTVIT
 JV
 JVANASCO
@@ -4876,6 +4897,7 @@ KNASSAR
 KNEW
 KNI
 KNIGHT
+KNM
 KNOEFEL
 KNOK
 KNOPKE
@@ -5166,6 +5188,7 @@ LEO
 LEOCHARRE
 LEOHUA
 LEON
+LEONMEDIA
 LEONOVPA
 LEONT
 LEPHT
@@ -5820,6 +5843,7 @@ MHYOUNG
 MICB
 MICHAEL
 MICHAELD
+MICHAELR
 MICHAELW
 MICHEL
 MICHELEO
@@ -6021,6 +6045,7 @@ MMWEBER
 MNAGUIB
 MNCOPPOLA
 MNDRIX
+MNEMONIC
 MNEYLON
 MNF
 MNIKHIL
@@ -6053,6 +6078,7 @@ MONTUORI
 MOO
 MOOCOW
 MOOLI
+MOOLLAZA
 MOON
 MOONRANBW
 MOOSA
@@ -6088,6 +6114,7 @@ MOXFYRE
 MOXNET
 MOZZERB
 MPAPP
+MPASTERN
 MPB
 MPCZ
 MPECK
@@ -6163,6 +6190,7 @@ MSCHILLI
 MSCHLUE
 MSCHMITT
 MSCHOUT
+MSCHUETT
 MSCHWARTZ
 MSCHWERN
 MSCROGGIN
@@ -6289,6 +6317,7 @@ MZRAHMAN
 MZSANFORD
 NAB
 NABESHIMA
+NABOJ
 NABU
 NACHBAUR
 NACHMORE
@@ -6853,6 +6882,7 @@ PERLXPERT
 PERNST
 PEROLI
 PERRAD
+PERRETTDL
 PERRIN
 PERSICOM
 PETAMEM
@@ -7214,6 +7244,7 @@ RADER
 RADEV
 RADFORD
 RADIANT
+RADIUS
 RADKOV
 RADOS
 RADPOC
@@ -7272,6 +7303,7 @@ RATLCC
 RATLIFFM
 RATTLER
 RATTR
+RAULMATEI
 RAVENHALL
 RAVENOR
 RAVN
@@ -7533,6 +7565,7 @@ RMORIZ
 RMOSE
 RMUHLE
 RMURRI
+RMV
 RNAIMA
 RNDLPH
 RNEWSHAM
@@ -7749,6 +7782,7 @@ SAGIVBA
 SAHAAB
 SAHIR
 SAIFUL
+SAILFREE
 SAILSDIG
 SAILTHRU
 SAINTMARK
@@ -7767,6 +7801,7 @@ SAMBAKKI
 SAMBAZZI
 SAMCORL
 SAMHELLER
+SAMIRCURY
 SAMLOWRIE
 SAMO
 SAMOD
@@ -8094,6 +8129,7 @@ SIERRA
 SIFUKURT
 SIGIN
 SIGIZ
+SIGJE
 SIGURKO
 SIGZERO
 SILASMONK
@@ -8163,6 +8199,7 @@ SKIMO
 SKINGTON
 SKIPPY
 SKIT
+SKJM
 SKMACPHE
 SKNPP
 SKOLYCHEV
@@ -9065,6 +9102,7 @@ UGANSERT
 UGEH
 UGEN
 UGEXE
+UGUTOMO
 UHANDA
 UHERBST
 UJIN
@@ -9185,6 +9223,7 @@ VILA
 VILEDA
 VILJUN
 VINAYSKI
+VINIAN
 VINSWORLD
 VIORELS
 VIOSCA
@@ -9610,6 +9649,7 @@ YSTH
 YSUZUKI
 YSYROTA
 YTURTLE
+YUDUBAN
 YUKI
 YUKINOBU
 YUKIO
