@@ -1,11 +1,13 @@
 package Acme::MetaSyntactic::quantum;
 use strict;
 use Acme::MetaSyntactic::List;
-our @ISA = qw(Acme::MetaSyntactic::List);
-our $VERSION = '1.000';
+our @ISA = qw( Acme::MetaSyntactic::List );
+our $VERSION = '1.001';
 __PACKAGE__->init();
 1;
 
+=encoding iso-8859-1
+
 =head1 NAME
 
 Acme::MetaSyntactic::quantum - The Quantum Mechanics theme
@@ -29,6 +31,9 @@ Introduced in Acme-MetaSyntactic version 0.22, published on May 16, 2005.
 Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
 published on May 7, 2012.
 
+Updated with an C<=encoding> pod command in version 1.001,
+published on May 14,2012
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
