@@ -2,10 +2,12 @@ package Acme::MetaSyntactic::teletubbies;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 __PACKAGE__->init();
 1;
 
+=encoding iso-8859-1
+
 =head1 NAME
 
 Acme::MetaSyntactic::teletubbies - The teletubbies theme
@@ -27,6 +29,9 @@ published on May 7, 2012.
 
 Thanks to Jrme Fenal, for inspiration over IRC.
 
+Updated with an C<=encoding> pod command in version 1.001,
+published on May 14,2012
+
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
